Struct Pwrr
#[repr(transparent)]pub struct Pwrr(pub u32);Expand description
Power register
Tuple Fields
0: u32Implementations
impl Pwrr
impl Pwrr
pub const fn set_autoff(&mut self, val: bool)
pub const fn set_autoff(&mut self, val: bool)
Auto-off mode
pub const fn vrefprot(&self) -> bool
pub const fn vrefprot(&self) -> bool
VREF+ protection: prevents the internal reference buffer from being disturbed by a conversion
pub const fn set_vrefprot(&mut self, val: bool)
pub const fn set_vrefprot(&mut self, val: bool)
VREF+ protection: prevents the internal reference buffer from being disturbed by a conversion
pub const fn vrefsecsmp(&self) -> bool
pub const fn vrefsecsmp(&self) -> bool
VREF+ second sample: doubles the sampling time of the reference
pub const fn set_vrefsecsmp(&mut self, val: bool)
pub const fn set_vrefsecsmp(&mut self, val: bool)
VREF+ second sample: doubles the sampling time of the reference